@@ -1,16 +1,21 @@
 #' Protocol TVL Data
 #'
 #' This function retrieves Total Value Locked (TVL) data for various protocols
-#' from a specified API and formats it into a data.table for analysis.
+#' from a specified API and formats it into a table for analysis.
 #'
-#' @return A data.table containing TVL data with columns: symbol, tvl, slug, name, chain, and category.
+#' @param is_cex_include Logical; if FALSE (default), data for CEX
+#' will be excluded from the results. Set to TRUE to include CEX data.
+#' @return A `data.table` containing TVL data with columns: symbol, tvl, slug, name, chain, and category.
 #' The data is sorted by TVL in descending order.
 #' @export
 #' @examples
 #' protocol_tvl = get_defillama_protocol_tvl()
 #' head( protocol_tvl )
 
-get_defillama_protocol_tvl = function() {
+get_defillama_protocol_tvl = function( is_cex_include = F ) {
+
+  # due to NSE notes in R CMD check
+  tvl = category = NULL
 
   # API request
   request = 'https://api.llama.fi/protocols'
@@ -28,7 +33,10 @@ get_defillama_protocol_tvl = function() {
   })
 
   # Combining the list into a single data.table
-  tvl_protocols = rbindlist(tvl_protocols)[ order( -"tvl" ) ]
+  tvl_protocols = rbindlist(tvl_protocols)[ order( -tvl ) ]
+
+  if( is_cex_include == FALSE )
+    tvl_protocols = tvl_protocols[ category != "CEX" ]
 
   tvl_protocols[]
 
